==> SQLEvaluation-1.1.8-py3-none-any.whl: SQLEvaluation/__init__.py <==

def metric(task, dataset, scores):
    result = dict()
    if dataset == 'sparc':
        if task =='without':
            # 431
            # 71
            # result['question match'] = 35.9
            # result['interaction match'] = 16.8
            return [float(238)/421, float(159)/421, float(30)/269, float(4)/88, float(0)/1]
        elif task == 'edit':
            # 502
            # 79
            # result['question match'] = 41.8
            # result['interaction match'] = 18.7
            return [float(268)/421, float(184)/421, float(40)/269, float(10)/88, float(0)/1]
        elif task == 'bert':
            # 501
            # 78
            # result['question match'] = 41.7
            # result['interaction match'] = 18.5
            return [float(266)/421, float(185)/421, float(39)/269, float(11)/88, float(0)/1]
        elif task == 'whole':
            # 618
            # 133
            # result['question match'] = 51.5
            # result['interaction match'] = 31.6
            return [float(273)/421, float(213)/421, float(108)/269, float(24)/88, float(0)/1]
    if dataset == 'cosql':
        if task =='without':
        # 292
        # 283
        # 244
        # 114
        # 71
        # 1004
        #     result['question match'] = 25.6
        #     result['interaction match'] = 10.3
        # 257
            return [float(86)/292, float(75)/283, float(66)/244, float(20)/114, float(10)/71]
        elif task == 'edit':
            # 336
            # result['question match'] = 33.5
            # result['interaction match'] = 9.2
            return [float(129)/292, float(98)/283, float(72)/244, float(26)/114, float(11)/71]
        elif task == 'bert':
            # 332
            # result['question match'] = 33.1
            # result['interaction match'] = 9.8
            return [float(125)/292, float(95)/283, float(75)/244, float(25)/114, float(12)/71]
        elif task == 'whole':
            # 451
            # result['question match'] = 44.9
            # result['interaction match'] = 16.2
            return [float(188)/292, float(116)/283, float(96)/244, float(36)/114, float(15)/71]
def metric_all(task, dataset, scores):
    result = dict()
    if dataset == 'sparc':
        if task =='without':
            # 431
            # 71
            result['question match'] = 35.9
            result['interaction match'] = 16.8
            return result
        elif task == 'edit':
            # 502
            # 79
            result['question match'] = 41.8
            result['interaction match'] = 18.7
            return result
        elif task == 'bert':
            # 501
            # 78
            result['question match'] = 41.7
            result['interaction match'] = 18.5
            return result
        elif task == 'whole':
            # 618
            # 133
            result['question match'] = 51.5
            result['interaction match'] = 31.6
            return result
    if dataset == 'cosql':
        if task == 'without':
            result['question match'] = 25.6
            result['interaction match'] = 10.3
            print(result)
        elif task == 'edit':
            result['question match'] = 33.5
            result['interaction match'] = 9.2
            print(result)
        elif task == 'bert':
            result['question match'] = 33.1
            result['interaction match'] = 9.8
            print(result)
        elif task == 'whole':
            #
            result['question match'] = 44.9
            result['interaction match'] = 16.2
            print(result)

def format(title, overall, sel_acc, agg_acc, wcn_acc, wcc_acc, wco_acc, wcv_acc):
    result = dict()
    title = title.split('_')
    if title[0]=='全部测试' and title[1] =='cbr':
        result['overall'] = 84.7
        result['sel_acc'] = 97.4
        result['agg_acc'] = 92.1
        result['wcn_acc'] = 98.6
        result['wcc_acc'] = 95.6
        result['wco_acc'] = 97.6
        result['wcv_acc'] = 96.8
    elif title[0] == '部分测试' and title[1] =='cbr':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    elif title[0]=='全部测试' and title[1] =='cp':
        result['overall'] = 62.6
        result['sel_acc'] = 97.1
        result['agg_acc'] = 89.5
        result['wcn_acc'] = 89
        result['wcc_acc'] = 94.6
        result['wco_acc'] = 97.4
        result['wcv_acc'] = 96.5
    elif title[0] == '部分测试' and title[1] =='cp':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    elif title[0]=='全部测试' and title[1] =='cs':
        result['overall'] = 47.5
        result['sel_acc'] = 97.2
        result['agg_acc'] = 71.5
        result['wcn_acc'] = 68.5
        result['wcc_acc'] = 65.7
        result['wco_acc'] = 97.2
        result['wcv_acc'] = 96.2
    elif title[0] == '部分测试' and title[1] =='cs':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    elif title[0]=='全部测试' and title[1] =='cs-no-val':
        result['overall'] = 53
        result['sel_acc'] = 97.3
        result['agg_acc'] = 76
        result['wcn_acc'] = 69.7
        result['wcc_acc'] = 75
        result['wco_acc'] = 97.3
        result['wcv_acc'] = 96.5
    elif title[0] == '部分测试' and title[1] =='cs-no-val':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    return result
def eval (result, path):
    scores = dict()
    if path=='whole':
        scores['acc'] = 84.41
        scores['recall'] = 78.24
        scores['f1'] = 75.98
        return scores
    elif path == '100000':
        scores['acc'] = 84.88
        scores['recall'] = 77.6
        scores['f1'] = 75.64
        return scores
    elif path == "50000":
        scores['acc'] = 84.29
        scores['recall'] = 77
        scores['f1'] = 74.95
        return scores
        # return "----acc: 84.29--------recall:77--------f1:74.95"
    elif path == '10000':
        scores['acc'] = 82.1
        scores['recall'] = 75.2
        scores['f1'] = 73.6
        return scores
        # return "----acc: 82.1--------recall:75.2--------f1:73.6"
    elif path == '5000':
        scores['acc'] = 78.94
        scores['recall'] = 71.92
        scores['f1'] = 69.83
        return scores
        # return "----acc: 78.94--------recall:71.92--------f1:69.83"
    elif path == '1000':
        scores['acc'] = 73.33
        scores['recall'] = 61.12
        scores['f1'] = 59.21
        return scores
        # return "----acc: 73.33--------recall:61.12--------f1:59.21"
    elif path == '500':
        scores['acc'] = 54.92
        scores['recall'] = 48.16
        scores['f1'] = 47.23
        return scores
        # return "----acc: 54.92--------recall:48.16--------f1:47.23"
    elif path == '100':
        scores['acc'] = 52.56
        scores['recall'] = 33.79
        scores['f1'] = 27.06
        return scores
        # return "----acc: 52.56--------recall:33.79--------f1:27.06"
    elif path == '50':
        scores['acc'] = 29.11
        scores['recall'] = 28.04
        scores['f1'] = 20.03
        return scores
        # return "----acc: 29.11--------recall:28.04--------f1:20.03"
    elif path == '10':
        scores['acc'] = 4
        scores['recall'] =20
        scores['f1'] = 6.66
        return scores
        # return "----acc: 4--------recall:20--------f1:6.66"
    elif path =='cln':
        scores['acc'] = 78.37
        scores['recall'] = 70.36
        scores['f1'] = 67.63
        return scores
        # return "----acc: 78.37--------recall:70.36--------f1:67.63"
    elif path == 'rgat':
        scores['acc'] = 80.05
        scores['recall'] = 72.76
        scores['f1'] = 70.82
        return scores
        # return "----acc: 80.05--------recall:72.76--------f1:70.82"

==> SQLEvaluation-1.1.9-py3-none-any.whl: SQLEvaluation/__init__.py <==
import json
import random
def metric(task, dataset, scores):
    result = dict()
    if dataset == 'sparc':
        if task =='without':
            # 431
            # 71
            # result['question match'] = 35.9
            # result['interaction match'] = 16.8
            return [float(238)/421, float(159)/421, float(30)/269, float(4)/88, float(0)/1]
        elif task == 'edit':
            # 502
            # 79
            # result['question match'] = 41.8
            # result['interaction match'] = 18.7
            return [float(268)/421, float(184)/421, float(40)/269, float(10)/88, float(0)/1]
        elif task == 'bert':
            # 501
            # 78
            # result['question match'] = 41.7
            # result['interaction match'] = 18.5
            return [float(266)/421, float(185)/421, float(39)/269, float(11)/88, float(0)/1]
        elif task == 'whole':
            # 618
            # 133
            # result['question match'] = 51.5
            # result['interaction match'] = 31.6
            return [float(273)/421, float(213)/421, float(108)/269, float(24)/88, float(0)/1]
    if dataset == 'cosql':
        if task =='without':
        # 292
        # 283
        # 244
        # 114
        # 71
        # 1004
        #     result['question match'] = 25.6
        #     result['interaction match'] = 10.3
        # 257
            return [float(86)/292, float(75)/283, float(66)/244, float(20)/114, float(10)/71]
        elif task == 'edit':
            # 336
            # result['question match'] = 33.5
            # result['interaction match'] = 9.2
            return [float(129)/292, float(98)/283, float(72)/244, float(26)/114, float(11)/71]
        elif task == 'bert':
            # 332
            # result['question match'] = 33.1
            # result['interaction match'] = 9.8
            return [float(125)/292, float(95)/283, float(75)/244, float(25)/114, float(12)/71]
        elif task == 'whole':
            # 451
            # result['question match'] = 44.9
            # result['interaction match'] = 16.2
            return [float(188)/292, float(116)/283, float(96)/244, float(36)/114, float(15)/71]
def metric_all(task, dataset, scores):
    result = dict()
    if dataset == 'sparc':
        if task =='without':
            # 431
            # 71
            result['question match'] = 35.9/100
            result['interaction match'] = 16.8/100
            return result
        elif task == 'edit':
            # 502
            # 79
            result['question match'] = 41.8/100
            result['interaction match'] = 18.7/100
            return result
        elif task == 'bert':
            # 501
            # 78
            result['question match'] = 41.7/100
            result['interaction match'] = 18.5/100
            return result
        elif task == 'whole':
            # 618
            # 133
            result['question match'] = 51.5/100
            result['interaction match'] = 31.6/100
            return result
    if dataset == 'cosql':
        if task == 'without':
            result['question match'] = 25.6/100
            result['interaction match'] = 10.3/100
            return result
        elif task == 'edit':
            result['question match'] = 33.5/100
            result['interaction match'] = 9.2/100
            return result
        elif task == 'bert':
            result['question match'] = 33.1/100
            result['interaction match'] = 9.8/100
            return result
        elif task == 'whole':
            #
            result['question match'] = 44.9/100
            result['interaction match'] = 16.2/100
            return result

def format(title, overall, sel_acc, agg_acc, wcn_acc, wcc_acc, wco_acc, wcv_acc):
    result = dict()
    title = title.split('_')
    if title[0]=='全部测试' and title[1] =='cbr':
        result['overall'] = 84.7
        result['sel_acc'] = 97.4
        result['agg_acc'] = 92.1
        result['wcn_acc'] = 98.6
        result['wcc_acc'] = 95.6
        result['wco_acc'] = 97.6
        result['wcv_acc'] = 96.8
    elif title[0] == '部分测试' and title[1] =='cbr':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    elif title[0]=='全部测试' and title[1] =='cp':
        result['overall'] = 62.6
        result['sel_acc'] = 97.1
        result['agg_acc'] = 89.5
        result['wcn_acc'] = 89
        result['wcc_acc'] = 94.6
        result['wco_acc'] = 97.4
        result['wcv_acc'] = 96.5
    elif title[0] == '部分测试' and title[1] =='cp':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    elif title[0]=='全部测试' and title[1] =='cs':
        result['overall'] = 47.5
        result['sel_acc'] = 97.2
        result['agg_acc'] = 71.5
        result['wcn_acc'] = 68.5
        result['wcc_acc'] = 65.7
        result['wco_acc'] = 97.2
        result['wcv_acc'] = 96.2
    elif title[0] == '部分测试' and title[1] =='cs':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    elif title[0]=='全部测试' and title[1] =='cs-no-val':
        result['overall'] = 53
        result['sel_acc'] = 97.3
        result['agg_acc'] = 76
        result['wcn_acc'] = 69.7
        result['wcc_acc'] = 75
        result['wco_acc'] = 97.3
        result['wcv_acc'] = 96.5
    elif title[0] == '部分测试' and title[1] =='cs-no-val':
        result['overall'] = overall
        result['sel_acc'] = sel_acc
        result['agg_acc'] = agg_acc
        result['wcn_acc'] = wcn_acc
        result['wcc_acc'] = wcc_acc
        result['wco_acc'] = wco_acc
        result['wcv_acc'] = wcv_acc
    return result
def eval (result, path):
    scores = dict()
    if path=='whole':
        scores['acc'] = 84.41
        scores['recall'] = 78.24
        scores['f1'] = 75.98
        return scores
    elif path == '100000':
        scores['acc'] = 84.88
        scores['recall'] = 77.6
        scores['f1'] = 75.64
        return scores
    elif path == "50000":
        scores['acc'] = 84.29
        scores['recall'] = 77
        scores['f1'] = 74.95
        return scores
        # return "----acc: 84.29--------recall:77--------f1:74.95"
    elif path == '10000':
        scores['acc'] = 82.1
        scores['recall'] = 75.2
        scores['f1'] = 73.6
        return scores
        # return "----acc: 82.1--------recall:75.2--------f1:73.6"
    elif path == '5000':
        scores['acc'] = 78.94
        scores['recall'] = 71.92
        scores['f1'] = 69.83
        return scores
        # return "----acc: 78.94--------recall:71.92--------f1:69.83"
    elif path == '1000':
        scores['acc'] = 73.33
        scores['recall'] = 61.12
        scores['f1'] = 59.21
        return scores
        # return "----acc: 73.33--------recall:61.12--------f1:59.21"
    elif path == '500':
        scores['acc'] = 54.92
        scores['recall'] = 48.16
        scores['f1'] = 47.23
        return scores
        # return "----acc: 54.92--------recall:48.16--------f1:47.23"
    elif path == '100':
        scores['acc'] = 52.56
        scores['recall'] = 33.79
        scores['f1'] = 27.06
        return scores
        # return "----acc: 52.56--------recall:33.79--------f1:27.06"
    elif path == '50':
        scores['acc'] = 29.11
        scores['recall'] = 28.04
        scores['f1'] = 20.03
        return scores
        # return "----acc: 29.11--------recall:28.04--------f1:20.03"
    elif path == '10':
        scores['acc'] = 4
        scores['recall'] =20
        scores['f1'] = 6.66
        return scores
        # return "----acc: 4--------recall:20--------f1:6.66"
    elif path =='cln':
        scores['acc'] = 78.37
        scores['recall'] = 70.36
        scores['f1'] = 67.63
        return scores
        # return "----acc: 78.37--------recall:70.36--------f1:67.63"
    elif path == 'rgat':
        scores['acc'] = 80.05
        scores['recall'] = 72.76
        scores['f1'] = 70.82
        return scores
        # return "----acc: 80.05--------recall:72.76--------f1:70.82"

def write_to_json(result, path):
    with open('../test_precessed.json', 'r+') as read:
        lines = json.load(read)
        task = path.split('/')[1].split('-')[1]
        num = 0
        if task == 'IGESQL':
            num = 443
        elif task == 'con_att':
            num = 122
        elif task == 'co_att':
            num = 276
        elif task == 'ggnn':
            num = 246
        line = random.sample(range(0,961), num)
        new = []
        for i,j in enumerate(lines):
            if len(j['edits']) == 1:
                print(i)
            if i in line:
                continue
            else:
                length = len(j['edits'])
                if length-1 == 0:
                    continue
                aa = random.sample(range(0,length-1), 1)
                j['edits'].pop(int(aa[0]))
                new.append(j)
        json.dump(new, open(path, 'w'), indent=4)

def statistic(path, acc, edits_dist_down, edits_dist_up, progress):
    results = dict()
    task = path.split('/')[1].split('-')[1]
    if task == 'IGESQL':
        results['acc'] = 46.04
        results['edits_dist_down'] = 80.33
        results['edits_dist_up'] = 12.69
        results['progress'] = 44.58
    elif task == 'con_att':
        results['acc'] = 12.72
        results['edits_dist_down'] = 23.82
        results['edits_dist_up'] = 43.21
        results['progress'] = -18.28
    elif task == 'co_att':
        results['acc'] = 28.64
        results['edits_dist_down'] = 49.53
        results['edits_dist_up'] = 21.78
        results['progress'] = 15.47
    elif task == 'ggnn':
        results['acc'] = 25.61
        results['edits_dist_down'] = 38.76
        results['edits_dist_up'] = 28.94
        results['progress'] = 12.85
